QuoteRequest

Struct QuoteRequest 

pub struct QuoteRequest {
    pub in_token_address: String,
    pub out_token_address: String,
    pub amount: String,
    pub slippage: Option<f64>,
    pub gas_price: Option<String>,
    pub disabled_dex_ids: Option<String>,
}
Quote request parameters

Fields

in_token_address: String

Input token address

out_token_address: String

Output token address

amount: String

Amount with decimals (e.g., “1000000000000000000” for 1 ETH)

slippage: Option<f64>

Slippage in percentage (e.g., 1 for 1%)

gas_price: Option<String>

Gas price in Gwei with decimals

disabled_dex_ids: Option<String>

Disabled DEX IDs (comma-separated)

Implementations

Source

impl QuoteRequest

pub fn new( in_token: impl Into<String>, out_token: impl Into<String>, amount: impl Into<String>, ) -> Self

Create a new quote request

pub fn with_slippage(self, slippage: f64) -> Self

Set slippage tolerance (must be between 0.01 and 50.0 percent)

Panics

Panics if slippage is outside the valid range (0.01..=50.0)

pub fn try_with_slippage(self, slippage: f64) -> Result<Self, String>

Set slippage tolerance with validation, returning an error if out of range

Slippage must be between 0.01% and 50%

pub fn with_gas_price(self, gas_price: impl Into<String>) -> Self

Set gas price in Gwei

pub fn with_disabled_dexs(self, dex_ids: impl Into<String>) -> Self

Disable specific DEX IDs